import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/financialManagement',
        redirect: '/financialManagement/warehousingConfirmation',
        component: PageView,
        meta: {
          title: '财务管理',
          icon: 'property-safety',
          permission: 'M_financialManagement'
        },
        children: [
          {
            path: '/financialManagement/warehousingConfirmation',
            redirect: '/financialManagement/warehousingConfirmation/list',
            name: 'warehousingConfirmation',
            component: BlankLayout,
            meta: {
              title: '入库确认',
              icon: 'vertical-align-bottom',
              permission: 'M_warehousingConfirmationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'warehousingConfirmationList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/warehousingConfirmation/list.vue'),
                meta: {
                  title: '入库确认列表',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_warehousingConfirmationList'
                }
              }
            ]
          },
          {
            path: '/financialManagement/financialCollection',
            redirect: '/financialManagement/financialCollection/list',
            name: 'financialCollection',
            component: BlankLayout,
            meta: {
              title: '财务收款',
              icon: 'pay-circle',
              permission: 'M_financialCollectionList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'financialCollectionList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/financialCollection/list.vue'),
                meta: {
                  title: '财务收款列表',
                  icon: 'pay-circle',
                  hidden: true,
                  permission: 'M_financialCollectionList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'financialCollectionDetail',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/financialCollection/detail.vue'),
                meta: {
                  title: '财务收款详情',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_fc_detail'
                }
              },
              {
                path: 'edit/:sn/:type',
                name: 'financialCollectionEdit',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/financialCollection/edit.vue'),
                meta: {
                  title: '编辑财务收款',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_fc_edit'
                }
              }
            ]
          },
          {
            path: '/financialManagement/collectionDetailStatic',
            redirect: '/financialManagement/collectionDetailStatic/list',
            name: 'collectionDetailStatic',
            component: BlankLayout,
            meta: {
              title: '财务收款明细统计',
              icon: 'vertical-align-top',
              permission: 'M_FC_Details_list'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'collectionDetailStaticList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/collectionDetailStatic/list.vue'),
                meta: {
                  title: '财务收款明细统计列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_FC_Details_list'
                }
              }
            ]
          },
          {
            path: '/financialManagement/accountStatement',
            redirect: '/financialManagement/accountStatement/list',
            name: 'accountStatement',
            component: BlankLayout,
            meta: {
              title: '对账单管理',
              icon: 'vertical-align-top',
              permission: 'M_accountStatement_list'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'accountStatementList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/accountStatement/list.vue'),
                meta: {
                  title: '对账单列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_accountStatement_list'
                }
              },
              {
                path: 'edit/:sn',
                name: 'accountStatementEdit',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/accountStatement/edit.vue'),
                meta: {
                  title: '编辑对账单',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_as_edit'
                }
              }
            ]
          },
          {
            path: '/financialManagement/accountStatementBill',
            redirect: '/financialManagement/accountStatementBill/list',
            name: 'accountStatementBill',
            component: BlankLayout,
            meta: {
              title: '经销商对账余额',
              icon: 'vertical-align-top',
              permission: 'M_accountStatementBill_list'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'accountStatementBillList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/accountStatementBill/list.vue'),
                meta: {
                  title: '待对单单据列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_accountStatementBill_list'
                }
              },
              {
                path: 'detail/:sn/:name/:type',
                name: 'accountStatementBillDetail',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/accountStatementBill/detail.vue'),
                meta: {
                  title: '待对单单据明细',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'B_asb_detail',
                  replaceTab: true,
                }
              },
            ]
          },
          {
            path: '/financialManagement/manualEntryForm',
            redirect: '/financialManagement/manualEntryForm/list',
            name: 'manualEntryForm',
            component: BlankLayout,
            meta: {
              title: '人工录入单',
              icon: 'vertical-align-top',
              permission: 'M_verifyAccountChange_list'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'manualEntryFormList',
                component: () => import(/* webpackChunkName: "financialManagement" */ '@/views/financialManagement/manualEntryForm/list.vue'),
                meta: {
                  title: '人工录入单列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_verifyAccountChange_list'
                }
              }
            ]
          }
        ]
      }